@@ -8,6 +8,7 @@ from channel_app.core.data import (CategoryTreeDto, CategoryNodeDto,
                                    CategoryAttributeDto,
                                    CategoryAttributeValueDto, ErrorReportDto,
                                    ChannelConfSchemaField)
+from channel_app.core.utilities import mock_response_decorator
 from channel_app.omnitron.constants import ChannelConfSchemaDataTypes
 
 
@@ -42,8 +43,8 @@ class GetCategoryTreeAndNodes(ChannelCommandInterface):
     def transform_data(self, data) -> object:
         return data
 
-    def send_request(self, validated_data) -> object:
-        response = self.__mocked_request(data=validated_data)
+    def send_request(self, transformed_data) -> object:
+        response = self.__mocked_request(data=transformed_data)
         return response
 
     def normalize_response(self, data, validated_data, transformed_data,
@@ -61,7 +62,7 @@ class GetCategoryTreeAndNodes(ChannelCommandInterface):
             "id": None,
             "name": "root",
             "parentId": None,
-            "subCategories": response["categories"]
+            "subCategories": response.json()["categories"]
         }
         # TODO document parent of top level nodes should be None
         # TODO document id and parent_id of root node must be None
@@ -92,6 +93,7 @@ class GetCategoryTreeAndNodes(ChannelCommandInterface):
 
         return category_tree, report, data
 
+    @mock_response_decorator
     def __mocked_request(self, data):
         """
         Mock a request and response for the send operation to mimic actual channel data
@@ -170,8 +172,8 @@ class GetCategoryAttributes(ChannelCommandInterface):
     def transform_data(self, data) -> object:
         return data
 
-    def send_request(self, validated_data) -> object:
-        response = self.__mocked_request(data=validated_data)
+    def send_request(self, transformed_data) -> object:
+        response = self.__mocked_request(data=transformed_data)
         return response
 
     def normalize_response(self, data, validated_data, transformed_data,
@@ -181,7 +183,7 @@ class GetCategoryAttributes(ChannelCommandInterface):
         requires
         """
         report = self.create_report(response)
-
+        response = response.json()
         category = CategoryDto(remote_id=response["id"],
                                name=response["name"],
                                attributes=[])
@@ -203,13 +205,13 @@ class GetCategoryAttributes(ChannelCommandInterface):
             category.attributes.append(attribute)
         return category, report, data
 
+    @mock_response_decorator
     def __mocked_request(self, data):
         """
         Mock a request and response for the send operation to mimic actual channel data
         """
-
         return {
-            "id": data.remote_id,
+            "id": 123123124214,
             "name": "Sweatshirt",
             "displayName": "Sweatshirt",
             "categoryAttributes": [
